/**
 ****************************************************************************************************
 * @file        bsp_flash.c
 * @author      HF_ZQ
 * @brief       STM32ڲFLASHд 
 * @license     Copyright (c) 2020-2050
 ****************************************************************************************************
 **/
//#include "./SYSTEM/usart/usart.h"
//#include "./SYSTEM/delay/delay.h"
#include "bsp_flash.h"

/**
 * @brief       ַָȡһ (32λ)
 * @param       faddr   : ȡַ (˵ַΪ4!!)
 * @retval      ȡ (32λ)
 */
uint32_t stmflash_read_word(uint32_t faddr)
{
    return *(volatile uint32_t *)faddr;
}

/**
 * @brief       ȡĳַڵflash
 * @param       addr    : lashַ
 * @retval      0~11,addrڵ
 */
uint8_t  stmflash_get_flash_sector(uint32_t addr)
{
    if (addr < ADDR_FLASH_SECTOR_1) return FLASH_SECTOR_0;
    else if (addr < ADDR_FLASH_SECTOR_2) return FLASH_SECTOR_1;
    else if (addr < ADDR_FLASH_SECTOR_3) return FLASH_SECTOR_2;
    else if (addr < ADDR_FLASH_SECTOR_4) return FLASH_SECTOR_3;
    else if (addr < ADDR_FLASH_SECTOR_5) return FLASH_SECTOR_4;
    else if (addr < ADDR_FLASH_SECTOR_6) return FLASH_SECTOR_5;
    else if (addr < ADDR_FLASH_SECTOR_7) return FLASH_SECTOR_6;
    else if (addr < ADDR_FLASH_SECTOR_8) return FLASH_SECTOR_7;
    else if (addr < ADDR_FLASH_SECTOR_9) return FLASH_SECTOR_8;
    else if (addr < ADDR_FLASH_SECTOR_10) return FLASH_SECTOR_9;
    else if (addr < ADDR_FLASH_SECTOR_11) return FLASH_SECTOR_10;
    return FLASH_SECTOR_11;
}

/**
 * @brief       FLASH ָλ, дָȵ(Զ)
 *   @note      ΪSTM32F4ʵ̫,û취ر,Աдַ0XFF
 *              ,ôȲҲ.д0XFFĵַ,ݶʧ.
 *              д֮ǰȷûҪ,Ȳ,Ȼд.
 *              úOTPҲЧ!дOTP!
 *              OTPַΧ:0X1FFF7800~0X1FFF7A0F(ע⣺16ֽڣOTPݿд)
 * @param       waddr   : ʼַ (˵ַΪ4ı!!,д!)
 * @param       pbuf    : ָ
 * @param       length  : Ҫд (32λ)(Ҫд32λݵĸ)
 * @retval      
 */
void stmflash_write(uint32_t waddr, uint32_t *pbuf, uint32_t length)
{
    FLASH_EraseInitTypeDef flasheraseinit;
    HAL_StatusTypeDef FlashStatus=HAL_OK;

    uint32_t addrx = 0;
    uint32_t endaddr = 0;
    uint32_t sectorerror=0;
    
    if (waddr < STM32_FLASH_BASE || waddr % 4 ||        /* дַС STM32_FLASH_BASE, 4, Ƿ. */
        waddr > (STM32_FLASH_BASE + STM32_FLASH_SIZE))  /* дַ STM32_FLASH_BASE + STM32_FLASH_SIZE, Ƿ. */
    {
        return;
    }

    HAL_FLASH_Unlock();             /*  */
    FLASH->ACR &= ~(1 << 10);       /* FLASHڼ,ֹݻ!!! */

    addrx = waddr;                  /* дʼַ */
    endaddr = waddr + length * 4;   /* дĽַ */

    if (addrx < 0X1FFF0000)         /* ֻ洢,Ҫִв!! */
    {
        while (addrx < endaddr)     /* ɨһϰ.(ԷFFFFFFFFĵط,Ȳ) */
        {
            if (stmflash_read_word(addrx) != 0XFFFFFFFF)    /* з0XFFFFFFFFĵط,Ҫ */
            {
                flasheraseinit.TypeErase=FLASH_TYPEERASE_SECTORS;       /* ͣ */
                flasheraseinit.Sector=stmflash_get_flash_sector(addrx); /* Ҫ */
                flasheraseinit.NbSectors=1;                             /* һֻһ */
                flasheraseinit.VoltageRange=FLASH_VOLTAGE_RANGE_3;      /* ѹΧVCC=2.7~3.6V֮!! */

                if(HAL_FLASHEx_Erase(&flasheraseinit, &sectorerror) != HAL_OK) 
                {
                    break;/*  */
                }

            }
            else
            {
                addrx += 4;
            }
            FLASH_WaitForLastOperation(FLASH_WAITETIME);                 /* ȴϴβ */
        }
    }

    FlashStatus=FLASH_WaitForLastOperation(FLASH_WAITETIME);             /* ȴϴβ */

    if (FlashStatus==HAL_OK)
    {
        while (waddr < endaddr)     /* д */
        {
            if (HAL_FLASH_Program(FLASH_TYPEPROGRAM_WORD, waddr, *pbuf) != HAL_OK)  /* д */
            {
                break;              /* д쳣 */
            }

            waddr += 4;
            pbuf++;
        }
    }
    
    FLASH->ACR |= 1 << 10;          /* FLASH,fetch */

    HAL_FLASH_Lock();               /*  */
}

/**
 * @brief       ַָʼָȵ
 * @param       raddr : ʼַ
 * @param       pbuf  : ָ
 * @param       length: Ҫȡ(32),4ֽڵ
 * @retval      
 */
void stmflash_read(uint32_t raddr, uint32_t *pbuf, uint32_t length)
{
    uint32_t i;

    for (i = 0; i < length; i++)
    {
        pbuf[i] = stmflash_read_word(raddr);    /* ȡ4ֽ. */
        raddr += 4; /* ƫ4ֽ. */
    }
}

/******************************************************************************************/
/* ô */

/**
 * @brief       д(д1)
 * @param       waddr : ʼַ
 * @param       wdata : Ҫд
 * @retval      ȡ
 */
void test_write(uint32_t waddr, uint32_t wdata)
{
    stmflash_write(waddr, &wdata, 1);   /* дһ */
}

